pub struct Profile {
pub servers: HashMap<String, ServerProfile>,
pub mutelist: HashMap<Uuid, String>,
pub transient_character: Option<CharacterProfile>,
pub tutorial: TutorialState,
}Expand description
Profile contains everything that can be configured in the profile.ron
Initially it is just for persisting things that don’t belong in settings.ron - like the state of hotbar and any other character level configuration.
Fields
servers: HashMap<String, ServerProfile>mutelist: HashMap<Uuid, String>transient_character: Option<CharacterProfile>Temporary character profile, used when it should not be persisted to the disk.
tutorial: TutorialStateImplementations
Sourceimpl Profile
impl Profile
Sourcepub fn load(config_dir: &Path) -> Self
pub fn load(config_dir: &Path) -> Self
Load the profile.ron file from the standard path or create it.
Sourcepub fn save_to_file_warn(&self, config_dir: &Path)
pub fn save_to_file_warn(&self, config_dir: &Path)
Save the current profile to disk, warn on failure.
Sourcepub fn get_hotbar_slots(
&self,
server: &str,
character_id: Option<CharacterId>,
) -> [Option<HotbarSlotContents>; 10]
pub fn get_hotbar_slots( &self, server: &str, character_id: Option<CharacterId>, ) -> [Option<HotbarSlotContents>; 10]
Get the hotbar_slots for the requested character_id.
If the server or character does not exist then the default hotbar_slots (empty) is returned.
Arguments
- server - current server the character is on.
- character_id - id of the character, passing
Noneindicates the transient character profile should be used.
Sourcepub fn set_hotbar_slots(
&mut self,
server: &str,
character_id: Option<CharacterId>,
slots: [Option<HotbarSlotContents>; 10],
)
pub fn set_hotbar_slots( &mut self, server: &str, character_id: Option<CharacterId>, slots: [Option<HotbarSlotContents>; 10], )
Set the hotbar_slots for the requested character_id.
If the server or character does not exist then the appropriate fields will be initialised and the slots added.
Arguments
- server - current server the character is on.
- character_id - id of the character, passing
Noneindicates the transient character profile should be used. - slots - array of hotbar_slots to save.
Sourcepub fn get_selected_character(&self, server: &str) -> Option<CharacterId>
pub fn get_selected_character(&self, server: &str) -> Option<CharacterId>
Get the selected_character for the provided server.
if the server does not exist then the default selected_character (None) is returned.
Arguments
- server - current server the character is on.
Sourcepub fn set_selected_character(
&mut self,
server: &str,
selected_character: Option<CharacterId>,
)
pub fn set_selected_character( &mut self, server: &str, selected_character: Option<CharacterId>, )
Set the selected_character for the provided server.
If the server does not exist then the appropriate fields will be initialised and the selected_character added.
Arguments
- server - current server the character is on.
- selected_character - option containing selected character ID
Sourcepub fn get_spectate_position(&self, server: &str) -> Option<Vec3<f32>>
pub fn get_spectate_position(&self, server: &str) -> Option<Vec3<f32>>
Get the selected_character for the provided server.
if the server does not exist then the default spectate_position (None) is returned.
Arguments
- server - current server the player is on.
Sourcepub fn set_spectate_position(
&mut self,
server: &str,
spectate_position: Option<Vec3<f32>>,
)
pub fn set_spectate_position( &mut self, server: &str, spectate_position: Option<Vec3<f32>>, )
Set the spectate_position for the provided server.
If the server does not exist then the appropriate fields will be initialised and the selected_character added.
Arguments
- server - current server the player is on.
- spectate_position - option containing the position we’re spectating
Sourcefn save_to_file(&self, config_dir: &Path) -> Result<()>
fn save_to_file(&self, config_dir: &Path) -> Result<()>
Save the current profile to disk.
fn get_path(config_dir: &Path) -> PathBuf